@@ -1,4 +1,7 @@
 import sys
+# Want this to fail quick for taking the ~1s that importing sympy takes.
+if len(sys.argv) == 1:
+        exit('enter a filename')
 from sympy import sympify, diff, latex
 from sympy.abc import *
 
@@ -44,8 +47,7 @@ def printFmtDerivatives():
             print(f'\tTeX deriv.{" " * 3}{derivativeLatex}')
 
 def main():
-    if len(sys.argv == 1):
-        exit('enter a filename')
+    
     printFmtDerivatives()
 
 if __name__ == '__main__':
